Sandbox

Trait Sandbox 

pub trait Sandbox: SandboxBackend {
    type Child: SandboxChild<Error = Self::Error>;
    type Error: Error + 'static;

    // Required methods
    fn prepare<'a>(
        &self,
        request: BackendRequest<'a>,
        context: &PathResolutionContext,
    ) -> Result<PreparedBackendRequest<'a, Self>, Self::Error>
       where Self: Sized;
    fn spawn<'a>(
        &self,
        prepared: PreparedBackendRequest<'a, Self>,
    ) -> Result<Self::Child, Self::Error>
       where Self: Sized;
}
Common preparation and process-launch contract for native Cageforge backends.

Required Associated Types

type Child: SandboxChild<Error = Self::Error>

The native child handle returned by Self::spawn.

type Error: Error + 'static

The native error type for preparation and launch.

Required Methods

fn prepare<'a>( &self, request: BackendRequest<'a>, context: &PathResolutionContext, ) -> Result<PreparedBackendRequest<'a, Self>, Self::Error>
where Self: Sized,

Validates a command and effective policy against this backend.

fn spawn<'a>( &self, prepared: PreparedBackendRequest<'a, Self>, ) -> Result<Self::Child, Self::Error>
where Self: Sized,

Launches one command in a new native sandbox boundary.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors